/**
 * @file
 * Improved user experience for the WIP colour widget.
 */
(function wipColorWidgetWrapper($, Drupal, once) {
  Drupal.behaviors.wipColorWidgetUX = {
    attach(context) {
      const containers = once(
        "wip-color-ux",
        ".wip-color-widget-container",
        context,
      );

      containers.forEach(function initializeWidget(widget) {
        const $widget = $(widget);
        const $radioButtons = $widget.find(".wip-color-type-selector");
        const $solidContainer = $widget.find(".wip-color-solid-container");
        const $gradientContainer = $widget.find(
          ".wip-color-gradient-container",
        );

        function updateContainerVisibility($selectedRadio) {
          const selectedType = $selectedRadio.val();

          $solidContainer.removeClass("is-visible");
          $gradientContainer.removeClass("is-visible");

          setTimeout(function showSelectedContainer() {
            if (selectedType === "solid") {
              $solidContainer.addClass("is-visible");
            } else if (selectedType === "gradient") {
              $gradientContainer.addClass("is-visible");
            }
          }, 50);
        }

        $radioButtons.on("change", function handleRadioChange() {
          updateContainerVisibility($(this));
        });

        setTimeout(function initializeSelectedState() {
          const $initialSelected = $radioButtons.filter(":checked");
          if ($initialSelected.length) {
            updateContainerVisibility($initialSelected);
          }
        }, 100);
      });
    },
  };
})(jQuery, Drupal, once);
